@@ -26,6 +26,8 @@
 #include <QtLocation/qplacereply.h>
 #include <QtLocation/qplacesearchrequest.h>
 #include <QtLocation/qplacesearchresult.h>
+
+QT_BEGIN_NAMESPACE
 class QGeoCodingManager;
 class QGeoCodingManagerEngine;
 class QGeoRoute;
@@ -52,6 +54,7 @@ class QPlaceSearchReply;
 class QPlaceSearchSuggestionReply;
 class QPlaceSupplier;
 class QPlaceUser;
+QT_END_NAMESPACE
 
 // Type indices
 enum [[deprecated]] : int {
@@ -204,6 +207,9 @@ enum : int {
 // This variable stores all Python types exported by this module.
 extern Shiboken::Module::TypeInitStruct *SbkPySide6_QtLocationTypeStructs;
 
+// This variable stores all Python types exported by this module in a backwards compatible way with identical indexing.
+[[deprecated]] extern PyTypeObject **SbkPySide6_QtLocationTypes;
+
 // This variable stores the Python module object exported by this module.
 extern PyObject *SbkPySide6_QtLocationModuleObject;
 
