@@ -1,12 +1,15 @@
 import os
 import sys
 from pathlib import Path
-from textwrap import dedent
+from types import ModuleType
+# mypy: disable-error-code="name-defined"
 
-# __all__ is also corrected below.
-__all__ = ["QtCore", "QtGui", "QtWidgets", "QtPrintSupport", "QtSql", "QtNetwork", "QtTest", "QtConcurrent", "QtDBus", "QtDesigner", "QtXml", "QtHelp", "QtMultimedia", "QtMultimediaWidgets", "QtOpenGL", "QtOpenGLWidgets", "QtPdf", "QtPdfWidgets", "QtPositioning", "QtLocation", "QtNetworkAuth", "QtNfc", "QtQml", "QtQuick", "QtQuick3D", "QtQuickControls2", "QtQuickTest", "QtQuickWidgets", "QtRemoteObjects", "QtScxml", "QtSensors", "QtSerialPort", "QtSerialBus", "QtStateMachine", "QtTextToSpeech", "QtCharts", "QtSpatialAudio", "QtSvg", "QtSvgWidgets", "QtDataVisualization", "QtGraphs", "QtBluetooth", "QtUiTools", "QtWebChannel", "QtWebEngineCore", "QtWebEngineWidgets", "QtWebEngineQuick", "QtWebSockets", "QtHttpServer", "Qt3DCore", "Qt3DRender", "Qt3DInput", "Qt3DLogic", "Qt3DAnimation", "Qt3DExtras"]
-__version__ = "6.7.3"
-__version_info__ = (6, 7, 3, "", "")
+# __all__ is computed below.
+__pre_all__ = ["QtCore", "QtGui", "QtWidgets", "QtPrintSupport", "QtSql", "QtNetwork", "QtTest", "QtConcurrent", "QtDBus", "QtDesigner", "QtXml", "QtHelp", "QtMultimedia", "QtMultimediaWidgets", "QtOpenGL", "QtOpenGLWidgets", "QtPdf", "QtPdfWidgets", "QtPositioning", "QtLocation", "QtNetworkAuth", "QtNfc", "QtQml", "QtQuick", "QtQuick3D", "QtQuickControls2", "QtQuickTest", "QtQuickWidgets", "QtRemoteObjects", "QtScxml", "QtSensors", "QtSerialPort", "QtSerialBus", "QtStateMachine", "QtTextToSpeech", "QtCharts", "QtSpatialAudio", "QtSvg", "QtSvgWidgets", "QtDataVisualization", "QtGraphs", "QtGraphsWidgets", "QtBluetooth", "QtUiTools", "QtWebChannel", "QtWebEngineCore", "QtWebEngineWidgets", "QtWebEngineQuick", "QtWebSockets", "QtHttpServer", "Qt3DCore", "Qt3DRender", "Qt3DInput", "Qt3DLogic", "Qt3DAnimation", "Qt3DExtras"]
+__version__ = "6.8.1.1"
+__version_info__ = (6, 8, 1.1, "", "")
+
+SKIP_MYPY_TEST = bool("")
 
 
 def _additional_dll_directories(package_dir):
@@ -16,7 +19,7 @@ def _additional_dll_directories(package_dir):
     if root.suffix == '.zip':
         return []
     shiboken6 = root / 'shiboken6'
-    if shiboken6.is_dir(): # Standard case, only shiboken6 is needed
+    if shiboken6.is_dir():  # Standard case, only shiboken6 is needed
         return [shiboken6]
     # The below code is for the build process when generate_pyi.py
     # is executed in the build directory. We need libpyside and Qt in addition.
@@ -29,9 +32,9 @@ def _additional_dll_directories(package_dir):
         result.append(libpysideqml)
     for path in os.environ.get('PATH').split(';'):
         if path:
-             if (Path(path) / 'qmake.exe').exists():
-                 result.append(path)
-                 break
+            if (Path(path) / 'qmake.exe').exists():
+                result.append(path)
+                break
     return result
 
 
@@ -59,6 +62,7 @@ def _setupQtDirectories():
     try:
         # PYSIDE-1497: we use the build dir or install dir or site-packages, whatever the path
         #              setting dictates. There is no longer a difference in path structure.
+        global Shiboken
         from shiboken6 import Shiboken
     except Exception:
         paths = ', '.join(sys.path)
@@ -95,20 +99,13 @@ def _find_all_qt_modules():
     # Since the wheel split, the __all__ variable cannot be computed statically,
     # because we don't know all modules in advance.
 
-    # Instead, we look into the file system and quickly build a list of all
-    # existing .pyi files, because importing is not desired and also impossible during import.
-    # By using the initially created list, we can keep some order intact.
+    # Instead, we use __getattr__ which is supported since Python 3.7
+    # and create the __all__ list on demand when needed.
     location = Path(__file__).resolve().parent
-
-    # Note: We should _not_ call this function while still building, but use the existing value!
-    in_build = Path("/build/pyside6/src/build") in location.parents
-
-    if in_build:
-        return __all__
-
     files = os.listdir(location)
-    unordered = set(name[:-4] for name in files if name.startswith("Qt") and name.endswith(".pyi"))
-    ordered_part = __all__
+    unordered = set(name[: name.find(".")] for name in files if name.startswith("Qt") and (
+                                                                name.endswith((".pyd", ".so"))))
+    ordered_part = __pre_all__
     result = []
     for name in ordered_part:
         if name in unordered:
@@ -118,5 +115,27 @@ def _find_all_qt_modules():
     return result
 
 
-__all__ = _find_all_qt_modules()
+# Provide the __all__ variable only on access.
+def __getattr__(name: str) -> list[str]:
+    if name == "__all__":
+        global __all__
+        __all__ = _find_all_qt_modules()
+        return __all__
+    raise AttributeError(f"module '{__name__}' has no attribute '{name}' :)")
+
+
+# Be prepared that people can access the module dict instead.
+class ModuleDict(dict):
+    def __missing__(self, key):
+        if key == "__all__":
+            self[key] = __all__ if "__all__" in globals() else __getattr__("__all__")
+            return __all__
+        raise KeyError(f"dict of module '{__name__}' has no key '{key}' :)")
+
+
+class SubModule(ModuleType):
+    pass
+
+
 _setupQtDirectories()
+Shiboken.replaceModuleDict(sys.modules["PySide6"], SubModule, ModuleDict(globals()))
